@@ -3,9 +3,9 @@ package Number::Phone::JP::Table::Class1;
 use strict;
 use warnings;
 
-our $VERSION = '0.20150304';
+our $VERSION = '0.20150402';
 
-# Table last modified: 2015-03-04
+# Table last modified: 2015-04-02
 our %TEL_TABLE = (
     # Pref => q<Assoc-Pref-Regex>,
     '01'    => '\d+', # KDDI
@@ -19,11 +19,7 @@ our %TEL_TABLE = (
     '037'   => '\d+', # フュージョンコミュニケーションズ
     '038'   => '\d+', # フュージョンコミュニケーションズ
     '039'   => '\d+', # NTT西日本
-    '041'   => '\d+', # ソフトバンクテレコム
-    '042'   => '\d+', # ソフトバンクテレコム
-    '043'   => '\d+', # ソフトバンクテレコム
-    '044'   => '\d+', # ソフトバンクテレコム
-    '045'   => '\d+', # ソフトバンクテレコム
+    '041'   => '\d+', # ソフトバンクモバイル
     '046'   => '\d+', # ソフトバンクモバイル
     '050'   => '\d+', # アルテリア・ネットワークス
     '051'   => '\d+', # KDDI
@@ -34,11 +30,11 @@ our %TEL_TABLE = (
     '056'   => '\d+', # KDDI
     '057'   => '\d+', # KDDI
     '060'   => '\d+', # アルテリア・ネットワークス
-    '061'   => '\d+', # ソフトバンクテレコム
-    '062'   => '\d+', # ソフトバンクテレコム
-    '063'   => '\d+', # ソフトバンクテレコム
-    '065'   => '\d+', # ソフトバンクテレコム
-    '066'   => '\d+', # ソフトバンクテレコム
+    '061'   => '\d+', # ソフトバンクモバイル
+    '062'   => '\d+', # ソフトバンクモバイル
+    '063'   => '\d+', # ソフトバンクモバイル
+    '065'   => '\d+', # ソフトバンクモバイル
+    '066'   => '\d+', # ソフトバンクモバイル
     '067'   => '\d+', # りーふねっと
     '070'   => '\d+', # KDDI
     '073'   => '\d+', # 安子の電話
@@ -47,11 +43,11 @@ our %TEL_TABLE = (
     '080'   => '\d+', # Tシステムズ・ジャパン
     '081'   => '\d+', # フュージョンコミュニケーションズ
     '082'   => '\d+', # フュージョンコミュニケーションズ
-    '083'   => '\d+', # ソフトバンクテレコム
-    '084'   => '\d+', # ソフトバンクテレコム
+    '083'   => '\d+', # ソフトバンクモバイル
+    '084'   => '\d+', # ソフトバンクモバイル
     '085'   => '\d+', # NTTメディアクロス
     '086'   => '\d+', # 九州通信ネットワーク
-    '088'   => '\d+', # ソフトバンクテレコム
+    '088'   => '\d+', # ソフトバンクモバイル
     '089'   => '\d+', # Tシステムズ・ジャパン
 );
 
